# Raven.js

Raven.js is a tiny standalone JavaScript client for [Sentry](http://www.getsentry.com/).

**Raven.js v1.1 requires Sentry v6.0 or later.**

## Resources

 * [Download](http://ravenjs.com)
 * [Documentation](http://raven-js.readthedocs.org)
 * [Bug Tracker](https://github.com/getsentry/raven-js/issues)
 * [IRC](irc://chat.freenode.net/sentry) (chat.freenode.net, #sentry)
 * Follow [@mattrobenolt](https://twitter.com/mattrobenolt) on Twitter for updates
